aboutsummaryrefslogtreecommitdiff
path: root/src/validation.cpp
diff options
context:
space:
mode:
authorTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
committerTomo Ueda <[email protected]>2021-09-02 12:55:18 -0700
commite64843ced509c24f783276d4cc0f2f26c9d527f2 (patch)
tree7956d4ea416c5b3a531dbc6f356e1c9a643d9690 /src/validation.cpp
parentreally s/doge/dis/g this time (diff)
downloaddiscoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.tar.xz
discoin-e64843ced509c24f783276d4cc0f2f26c9d527f2.zip
really s/Doge/Dis/g this time
Diffstat (limited to 'src/validation.cpp')
-rw-r--r--src/validation.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/validation.cpp b/src/validation.cpp
index f4ec502d3..b6d6a4886 100644
--- a/src/validation.cpp
+++ b/src/validation.cpp
@@ -52,7 +52,7 @@
#include <boost/thread.hpp>
#if defined(NDEBUG)
# error "Dogecoin cannot be compiled without assertions."
#endif
/**
@@ -100,7 +100,7 @@ static void CheckBlockIndex(const Consensus::Params& consensusParams);
/** Constant stuff for coinbase transactions we create: */
CScript COINBASE_FLAGS;
-const std::string strMessageMagic = "Dogecoin Signed Message:\n";
+const std::string strMessageMagic = "Discoin Signed Message:\n";
// Internal stuff
namespace {
@@ -797,7 +797,7 @@ bool AcceptToMemoryPoolWorker(CTxMemPool& pool, CValidationState& state, const C
// Continuously rate-limit free (really, very-low-fee) transactions
// This mitigates 'penny-flooding' -- sending thousands of free transactions just to
// be annoying or make others' transactions take longer to confirm.
- if (fLimitFree && nModifiedFees < GetDogecoinMinRelayFee(tx, nSize, !fLimitFree))
+ if (fLimitFree && nModifiedFees < GetDiscoinMinRelayFee(tx, nSize, !fLimitFree))
{
static CCriticalSection csFreeLimiter;
static double dFreeCount;
@@ -1431,7 +1431,7 @@ bool CheckTxInputs(const CChainParams& params, const CTransaction& tx, CValidati
// If prev is coinbase, check that it's matured
if (coins->IsCoinBase()) {
// Dogecoin: Switch maturity at depth 145,000
int nCoinbaseMaturity = params.GetConsensus(coins->nHeight).nCoinbaseMaturity;
if (nSpendHeight - coins->nHeight < nCoinbaseMaturity)
return state.Invalid(false,
@@ -1847,7 +1847,7 @@ bool ConnectBlock(const CBlock& block, CValidationState& state, CBlockIndex* pin
// Now that the whole chain is irreversibly beyond that time it is applied to all blocks except the
// two in the chain that violate it. This prevents exploiting the issue against nodes during their
// initial block download.
// Dogecoin: BIP30 has been active since inception
bool fEnforceBIP30 = true;
// Once BIP34 activated it was not possible to create new duplicate coinbases and thus other than starting
@@ -1870,7 +1870,7 @@ bool ConnectBlock(const CBlock& block, CValidationState& state, CBlockIndex* pin
}
// BIP16 didn't become active until Apr 1 2012
// Dogecoin: BIP16 has been enabled since inception
bool fStrictPayToScriptHash = true;
unsigned int flags = fStrictPayToScriptHash ? SCRIPT_VERIFY_P2SH : SCRIPT_VERIFY_NONE;
@@ -1975,7 +1975,7 @@ bool ConnectBlock(const CBlock& block, CValidationState& state, CBlockIndex* pin
int64_t nTime3 = GetTimeMicros(); nTimeConnect += nTime3 - nTime2;
LogPrint("bench", " - Connect %u transactions: %.2fms (%.3fms/tx, %.3fms/txin) [%.2fs]\n", (unsigned)block.vtx.size(), 0.001 * (nTime3 - nTime2), 0.001 * (nTime3 - nTime2) / block.vtx.size(), nInputs <= 1 ? 0 : 0.001 * (nTime3 - nTime2) / (nInputs-1), nTimeConnect * 0.000001);
- CAmount blockReward = nFees + GetDogecoinBlockSubsidy(pindex->nHeight, chainparams.GetConsensus(pindex->nHeight), hashPrevBlock);
+ CAmount blockReward = nFees + GetDiscoinBlockSubsidy(pindex->nHeight, chainparams.GetConsensus(pindex->nHeight), hashPrevBlock);
if (block.vtx[0]->GetValueOut() > blockReward)
return state.DoS(100,
error("ConnectBlock(): coinbase pays too much (actual=%d vs limit=%d)",
@@ -2997,7 +2997,7 @@ static bool CheckIndexAgainstCheckpoint(const CBlockIndex* pindexPrev, CValidati
bool IsWitnessEnabled(const CBlockIndex* pindexPrev, const Consensus::Params& params)
{
// Dogecoin: Disable SegWit
return false;
// LOCK(cs_main);
// return (VersionBitsState(pindexPrev, params, Consensus::DEPLOYMENT_SEGWIT, versionbitscache) == THRESHOLD_ACTIVE);
@@ -3071,7 +3071,7 @@ bool ContextualCheckBlockHeader(const CBlockHeader& block, CValidationState& sta
__func__),
REJECT_INVALID, "late-legacy-block");
// Dogecoin: Disallow AuxPow blocks before it is activated.
// TODO: Remove this test, as checkpoints will enforce this for us now
// NOTE: Previously this had its own fAllowAuxPoW flag, but that's always the opposite of fAllowLegacyBlocks
if (consensusParams.fAllowLegacyBlocks
@@ -3094,7 +3094,7 @@ bool ContextualCheckBlockHeader(const CBlockHeader& block, CValidationState& sta
// Reject outdated version blocks when 95% (75% on testnet) of the network has upgraded:
// check for version 2, 3 and 4 upgrades
// Dogecoin: Version 2 enforcement was never used
if((block.GetBaseVersion() < 3 && nHeight >= consensusParams.BIP66Height) ||
(block.GetBaseVersion() < 4 && nHeight >= consensusParams.BIP65Height))
return state.Invalid(false, REJECT_OBSOLETE, strprintf("bad-version(0x%08x)", block.GetBaseVersion()),
@@ -3110,7 +3110,7 @@ bool ContextualCheckBlock(const CBlock& block, CValidationState& state, const CB
const Consensus::Params& consensusParams = chainParams.GetConsensus(nHeight);
// Start enforcing BIP113 (Median Time Past) using versionbits logic.
// Dogecoin: We probably want to disable this
int nLockTimeFlags = 0;
if (VersionBitsState(pindexPrev, consensusParams, Consensus::DEPLOYMENT_CSV, versionbitscache) == THRESHOLD_ACTIVE) {
nLockTimeFlags |= LOCKTIME_MEDIAN_TIME_PAST;
@@ -52,7 +52,7 @@
#include <boost/thread.hpp>
#if defined(NDEBUG)
-# error "Dogecoin cannot be compiled without assertions."
+# error "Discoin cannot be compiled without assertions."
#endif
/**
@@ -1431,7 +1431,7 @@ bool CheckTxInputs(const CChainParams& params, const CTransaction& tx, CValidati
// If prev is coinbase, check that it's matured
if (coins->IsCoinBase()) {
- // Dogecoin: Switch maturity at depth 145,000
+ // Discoin: Switch maturity at depth 145,000
int nCoinbaseMaturity = params.GetConsensus(coins->nHeight).nCoinbaseMaturity;
if (nSpendHeight - coins->nHeight < nCoinbaseMaturity)
@@ -1847,7 +1847,7 @@ bool ConnectBlock(const CBlock& block, CValidationState& state, CBlockIndex* pin
// two in the chain that violate it. This prevents exploiting the issue against nodes during their
// initial block download.
- // Dogecoin: BIP30 has been active since inception
+ // Discoin: BIP30 has been active since inception
bool fEnforceBIP30 = true;
// Once BIP34 activated it was not possible to create new duplicate coinbases and thus other than starting
@@ -1870,7 +1870,7 @@ bool ConnectBlock(const CBlock& block, CValidationState& state, CBlockIndex* pin
}
// BIP16 didn't become active until Apr 1 2012
- // Dogecoin: BIP16 has been enabled since inception
+ // Discoin: BIP16 has been enabled since inception
bool fStrictPayToScriptHash = true;
unsigned int flags = fStrictPayToScriptHash ? SCRIPT_VERIFY_P2SH : SCRIPT_VERIFY_NONE;
@@ -2997,7 +2997,7 @@ static bool CheckIndexAgainstCheckpoint(const CBlockIndex* pindexPrev, CValidati
bool IsWitnessEnabled(const CBlockIndex* pindexPrev, const Consensus::Params& params)
{
- // Dogecoin: Disable SegWit
+ // Discoin: Disable SegWit
return false;
// LOCK(cs_main);
@@ -3071,7 +3071,7 @@ bool ContextualCheckBlockHeader(const CBlockHeader& block, CValidationState& sta
__func__),
REJECT_INVALID, "late-legacy-block");
- // Dogecoin: Disallow AuxPow blocks before it is activated.
+ // Discoin: Disallow AuxPow blocks before it is activated.
// TODO: Remove this test, as checkpoints will enforce this for us now
// NOTE: Previously this had its own fAllowAuxPoW flag, but that's always the opposite of fAllowLegacyBlocks
@@ -3094,7 +3094,7 @@ bool ContextualCheckBlockHeader(const CBlockHeader& block, CValidationState& sta
// Reject outdated version blocks when 95% (75% on testnet) of the network has upgraded:
// check for version 2, 3 and 4 upgrades
- // Dogecoin: Version 2 enforcement was never used
+ // Discoin: Version 2 enforcement was never used
if((block.GetBaseVersion() < 3 && nHeight >= consensusParams.BIP66Height) ||
(block.GetBaseVersion() < 4 && nHeight >= consensusParams.BIP65Height))
@@ -3110,7 +3110,7 @@ bool ContextualCheckBlock(const CBlock& block, CValidationState& state, const CB
const Consensus::Params& consensusParams = chainParams.GetConsensus(nHeight);
// Start enforcing BIP113 (Median Time Past) using versionbits logic.
- // Dogecoin: We probably want to disable this
+ // Discoin: We probably want to disable this
int nLockTimeFlags = 0;
if (VersionBitsState(pindexPrev, consensusParams, Consensus::DEPLOYMENT_CSV, versionbitscache) == THRESHOLD_ACTIVE) {